import React, { PureComponent } from 'react';
import './coupons.scss'

import ExchangeaBar from "./ExchangeBar";
import Coupon from './Coupon'
import { http, api } from '@/utils'
import { WithFullSize } from '@/HOCs'
import { Toast } from 'antd-mobile'

const mockData = {
    valid: [
        {
            type: 1,
            couponName: '代金券',
            expire_time: '2017-12-31',
            limit: '可用于大于代金券金额的课程',
            denomination: '5'
        },
        {
            type: 2,
            couponName: '代金券',
            expire_time: '2017-12-31',
            limit: '可用于大于代金券金额的课程',
            denomination: '5'
        },
    ],
    invalid: [
        {
            type: 1,
            couponName: '代金券',
            expire_time: '2017-12-31',
            limit: '可用于大于代金券金额的课程',
            denomination: '5'
        },
        {
            type: 1,
            couponName: '代金券',
            expire_time: '2017-12-31',
            limit: '可用于大于代金券金额的课程',
            denomination: '5'
        },
    ]
}


class UseCoupon extends PureComponent {

    state = {
        selected: true,
        selectedCouponId: 0,
        exchangeCode: '',
        couponList: [],
        valid_coupons: [],
        invalid_coupons: [],
        inuse_coupon: []
    }

    componentDidMount() {
        const {state} = this.props.location
        if (state && state.from) {
            switch (state.from) {
                case '/my' :
                    this.getMyCoupons();
                    break;
                default:
                    this.getAllCoupons();
            }
        } else {
            this.getAllCoupons()
        }
    }

    select = val => {
        this.setState(state => {
            console.log(state.selected, state.selectedCouponId)
            return {
                selected: !state.selected,
                selectedCouponId: val
            }
        })
    }

    handleChange = val => {
        this.setState({exchangeCode: val})
    }

    exchange = () => {
        if (this.state.exchangeCode !== '') {
            http.post(`${api.home}/m/coupon/exchange`, {
                code: this.state.exchangeCode
            })
                .then(res => {
                    const data = res.data
                    if (data.code === 200) {
                        this.setState({
                            couponList: [data.data, ...this.state.couponList]
                        })
                        Toast.info('兑换成功')
                    } else {
                        Toast.fail(data.msg)
                    }
                })
        } else {
            Toast.info('请输入兑换码')
        }
    }

    getMyCoupons = () => {
        http.get(`${api.home}/m/coupon/all`)
            .then(res => {
                const data = res.data
                if (data.code === 200) {
                    this.setState({
                        couponList: data.data,
                        selectedCouponId: data.data[0].id
                    })
                } else {
                    Toast.fail(data.msg)
                }
            })
    }

    getAllCoupons = () => {
        http.post(`${api.home}/m/coupon/select`, {course_id: 139})
            .then(res => {
                const data = res.data
                if (data.code === 200) {

                    this.setState({
                        valid_coupons: data.data.valid_coupons,
                        invalid_coupons: data.data.invalid_coupons,
                        inuse_coupon: data.data.inuse_coupon
                    })

                } else {
                    Toast.fail(data.msg)
                }
            })
    }

    selectCoupon = () => {

    }

    render() {
        const {state} = this.props.location
        return (
            <div className='use-coupon'>
                <ExchangeaBar onChange={this.handleChange}
                              exchange={this.exchange}
                              exchangeCode={this.state.exchangeCode}/>
                <div className="coupons-area">
                    <Content
                        coupons={state && state.from && state.from === '/my' ? this.state.couponList : this.state.valid_coupons}
                        showUseButton={false}
                        selected={this.state.selected}
                        selectedCouponId={this.state.selectedCouponId}
                        select={this.select}
                        purpose={'use'}
                    />
                    {
                        this.state.invalid_coupons.length > 0 &&
                        (
                            <>
                                <div className='invalid-title'>- 不可使用的优惠券 -</div>
                                <Content
                                    coupons={this.state.invalid_coupons}
                                    selected={this.state.selected}
                                    selectedCouponId={this.state.selectedCouponId}
                                    select={this.select}
                                    purpose={'use'}
                                    invalid={'invalid'}
                                />
                            </>
                        )
                    }
                </div>
            </div>
        );
    }
}

function Content({coupons, selected, ...rest}) {
    if (coupons.length === 0) {
        return (
            <div className='empty'>
                <p>暂无可使用的优惠券</p>
            </div>
        )
    }
    return (
        <ul>
            {
                coupons.map(item => {
                    return (
                        <Coupon
                            key={item.id}
                            {...item}
                            selected={selected}
                            id={item.id}
                            {...rest}
                        />
                    )
                })
            }
        </ul>
    )
}

export default WithFullSize(UseCoupon);